/*
** This program allows the user to view the various 75 dot/inch fonts
** available on the X server.
**
** Preprocess this file using "et2c" then link with "et.o".
*/
#include "tk.h"     /* This automatically loads Xlib.h */

void main(int argc, char **argv){
  Et_Init(&argc,argv);
  ET_INSTALL_COMMANDS;
  ET(
    wm title . "Font Test"
    wm minsize . 1 1
    frame .f -bd 2 -relief raised
    listbox .f.box -yscrollcommand ".f.sb set"
    scrollbar .f.sb -orient vertical -command ".f.box yview"
    label .l1 -text "Example Text" -bd 2 -relief raised
    label .l2 -text "The quick fox jumps over the lazy brown dog." \
        -bd 2 -relief raised
    label .mesg -text ""
    pack .f.box -side left -expand 1 -fill both
    pack .f.sb -fill y -side right
    pack .f -expand 1 -side top -fill both
    pack .l1 .l2 .mesg -side top
    FillBox
    bind .f.box <Double-Button-1> {SetFont [selection get]}
  );
  Et_MainLoop();
}

/* This function is called to fill the listbox at ".f.box" with then
** names of all non-scalable 75 dot/inch fonts known to the server.
*/
ET_PROC( FillBox ){
  char **fontnames;    /* The names of all 75 dot/inch fonts */
  int count;           /* Number of 75 dot/inch fonts */
  int i;               /* Loop counter */

  fontnames = XListFonts(Et_Display,"*-75-75-*-*-iso8859-1",1000,&count);
  for(i=0; i<count; i++){
    int k;
    char *cp;
    cp = fontnames[i];
    k = 0;
    while( *cp && k<7 ){
      if( *cp=='-' ) k++;
      cp++;
    }
    if( *cp=='0' ) continue;
    ET( .f.box insert end {%s(fontnames[i])});
  }
  XFreeFontNames(fontnames);
  return ET_OK;
}

/* This function sets the example text to the font named in the first
** (and only) argument.  It also prints metric information about that
** font in the ".mesg" window.
*/
ET_PROC( SetFont ){
  XFontStruct *font;    /* Information about a particular font */

  font = XLoadQueryFont(Et_Display,argv[1]);
  ET( .l1 config -font %s(argv[1]); .l2 config -font %s(argv[1]));
  ET( .mesg config -text {
     ascent = %d(font->ascent)\
     descent = %d(font->descent)\
     width = %d(font->min_bounds.width)..%d(font->max_bounds.width)});
  return ET_OK;
}
